@@ -9,6 +9,8 @@ from enum import Enum
 from oauthlib.oauth2 import LegacyApplicationClient
 from requests_oauthlib import OAuth2Session
 
+from .error import EloquaException
+
 try:
     from urllib import urlencode
 except ImportError:
@@ -21,17 +23,6 @@ API_VERSION = '2.0'
 TOKEN_URL = LOGIN_URL + '/auth/oauth2/token'
 
 
-class EloquaException(Exception):
-
-    def __init__(self, reason, text):
-        self.reason = reason
-        self.text = text
-
-    def __str__(self):
-        return "Eloqua API Error: {}, reason: {}".format(
-            self.text, self.reason)
-
-
 class AuthType(Enum):
     BASIC = 1,
     OAUTH2 = 2
